==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/ASLEFTTESTPOINTSDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour ASLEFTTESTPOINTSDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASLEFTTESTPOINTSDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTSTANDARDVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTSTANDARDVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTOUTPUTVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTOUTPUTVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVICEREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVIATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVICETOLERANCEFROM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVICETOLERANCETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASLEFTTESTPOINTSDETAILS_Type", propOrder = {
    "asleftstandardvalue",
    "asleftstandardvalueuom",
    "asleftoutputvalue",
    "asleftoutputvalueuom",
    "asleftdevicereading",
    "asleftdeviation",
    "asleftdevicetolerancefrom",
    "asleftdevicetoleranceto",
    "asleftstatus"
})
public class ASLEFTTESTPOINTSDETAILS_Type {

    @XmlElement(name = "ASLEFTSTANDARDVALUE")
    protected QUANTITY asleftstandardvalue;
    @XmlElement(name = "ASLEFTSTANDARDVALUEUOM")
    protected UOMID_Type asleftstandardvalueuom;
    @XmlElement(name = "ASLEFTOUTPUTVALUE")
    protected QUANTITY asleftoutputvalue;
    @XmlElement(name = "ASLEFTOUTPUTVALUEUOM")
    protected UOMID_Type asleftoutputvalueuom;
    @XmlElement(name = "ASLEFTDEVICEREADING")
    protected QUANTITY asleftdevicereading;
    @XmlElement(name = "ASLEFTDEVIATION")
    protected QUANTITY asleftdeviation;
    @XmlElement(name = "ASLEFTDEVICETOLERANCEFROM")
    protected QUANTITY asleftdevicetolerancefrom;
    @XmlElement(name = "ASLEFTDEVICETOLERANCETO")
    protected QUANTITY asleftdevicetoleranceto;
    @XmlElement(name = "ASLEFTSTATUS")
    protected STATUS_Type asleftstatus;

    /**
     * Obtient la valeur de la propriété asleftstandardvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTSTANDARDVALUE() {
        return asleftstandardvalue;
    }

    /**
     * Définit la valeur de la propriété asleftstandardvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTSTANDARDVALUE(QUANTITY value) {
        this.asleftstandardvalue = value;
    }

    /**
     * Obtient la valeur de la propriété asleftstandardvalueuom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASLEFTSTANDARDVALUEUOM() {
        return asleftstandardvalueuom;
    }

    /**
     * Définit la valeur de la propriété asleftstandardvalueuom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASLEFTSTANDARDVALUEUOM(UOMID_Type value) {
        this.asleftstandardvalueuom = value;
    }

    /**
     * Obtient la valeur de la propriété asleftoutputvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTOUTPUTVALUE() {
        return asleftoutputvalue;
    }

    /**
     * Définit la valeur de la propriété asleftoutputvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTOUTPUTVALUE(QUANTITY value) {
        this.asleftoutputvalue = value;
    }

    /**
     * Obtient la valeur de la propriété asleftoutputvalueuom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASLEFTOUTPUTVALUEUOM() {
        return asleftoutputvalueuom;
    }

    /**
     * Définit la valeur de la propriété asleftoutputvalueuom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASLEFTOUTPUTVALUEUOM(UOMID_Type value) {
        this.asleftoutputvalueuom = value;
    }

    /**
     * Obtient la valeur de la propriété asleftdevicereading.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVICEREADING() {
        return asleftdevicereading;
    }

    /**
     * Définit la valeur de la propriété asleftdevicereading.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVICEREADING(QUANTITY value) {
        this.asleftdevicereading = value;
    }

    /**
     * Obtient la valeur de la propriété asleftdeviation.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVIATION() {
        return asleftdeviation;
    }

    /**
     * Définit la valeur de la propriété asleftdeviation.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVIATION(QUANTITY value) {
        this.asleftdeviation = value;
    }

    /**
     * Obtient la valeur de la propriété asleftdevicetolerancefrom.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVICETOLERANCEFROM() {
        return asleftdevicetolerancefrom;
    }

    /**
     * Définit la valeur de la propriété asleftdevicetolerancefrom.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVICETOLERANCEFROM(QUANTITY value) {
        this.asleftdevicetolerancefrom = value;
    }

    /**
     * Obtient la valeur de la propriété asleftdevicetoleranceto.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVICETOLERANCETO() {
        return asleftdevicetoleranceto;
    }

    /**
     * Définit la valeur de la propriété asleftdevicetoleranceto.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVICETOLERANCETO(QUANTITY value) {
        this.asleftdevicetoleranceto = value;
    }

    /**
     * Obtient la valeur de la propriété asleftstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getASLEFTSTATUS() {
        return asleftstatus;
    }

    /**
     * Définit la valeur de la propriété asleftstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setASLEFTSTATUS(STATUS_Type value) {
        this.asleftstatus = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/ASLEFTTESTPOINTSDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for ASLEFTTESTPOINTSDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASLEFTTESTPOINTSDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTSTANDARDVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTSTANDARDVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTOUTPUTVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTOUTPUTVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVICEREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVIATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVICETOLERANCEFROM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTDEVICETOLERANCETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASLEFTSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASLEFTTESTPOINTSDETAILS_Type", propOrder = {
    "asleftstandardvalue",
    "asleftstandardvalueuom",
    "asleftoutputvalue",
    "asleftoutputvalueuom",
    "asleftdevicereading",
    "asleftdeviation",
    "asleftdevicetolerancefrom",
    "asleftdevicetoleranceto",
    "asleftstatus"
})
public class ASLEFTTESTPOINTSDETAILS_Type {

    @XmlElement(name = "ASLEFTSTANDARDVALUE")
    protected QUANTITY asleftstandardvalue;
    @XmlElement(name = "ASLEFTSTANDARDVALUEUOM")
    protected UOMID_Type asleftstandardvalueuom;
    @XmlElement(name = "ASLEFTOUTPUTVALUE")
    protected QUANTITY asleftoutputvalue;
    @XmlElement(name = "ASLEFTOUTPUTVALUEUOM")
    protected UOMID_Type asleftoutputvalueuom;
    @XmlElement(name = "ASLEFTDEVICEREADING")
    protected QUANTITY asleftdevicereading;
    @XmlElement(name = "ASLEFTDEVIATION")
    protected QUANTITY asleftdeviation;
    @XmlElement(name = "ASLEFTDEVICETOLERANCEFROM")
    protected QUANTITY asleftdevicetolerancefrom;
    @XmlElement(name = "ASLEFTDEVICETOLERANCETO")
    protected QUANTITY asleftdevicetoleranceto;
    @XmlElement(name = "ASLEFTSTATUS")
    protected STATUS_Type asleftstatus;

    /**
     * Gets the value of the asleftstandardvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTSTANDARDVALUE() {
        return asleftstandardvalue;
    }

    /**
     * Sets the value of the asleftstandardvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTSTANDARDVALUE(QUANTITY value) {
        this.asleftstandardvalue = value;
    }

    /**
     * Gets the value of the asleftstandardvalueuom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASLEFTSTANDARDVALUEUOM() {
        return asleftstandardvalueuom;
    }

    /**
     * Sets the value of the asleftstandardvalueuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASLEFTSTANDARDVALUEUOM(UOMID_Type value) {
        this.asleftstandardvalueuom = value;
    }

    /**
     * Gets the value of the asleftoutputvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTOUTPUTVALUE() {
        return asleftoutputvalue;
    }

    /**
     * Sets the value of the asleftoutputvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTOUTPUTVALUE(QUANTITY value) {
        this.asleftoutputvalue = value;
    }

    /**
     * Gets the value of the asleftoutputvalueuom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASLEFTOUTPUTVALUEUOM() {
        return asleftoutputvalueuom;
    }

    /**
     * Sets the value of the asleftoutputvalueuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASLEFTOUTPUTVALUEUOM(UOMID_Type value) {
        this.asleftoutputvalueuom = value;
    }

    /**
     * Gets the value of the asleftdevicereading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVICEREADING() {
        return asleftdevicereading;
    }

    /**
     * Sets the value of the asleftdevicereading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVICEREADING(QUANTITY value) {
        this.asleftdevicereading = value;
    }

    /**
     * Gets the value of the asleftdeviation property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVIATION() {
        return asleftdeviation;
    }

    /**
     * Sets the value of the asleftdeviation property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVIATION(QUANTITY value) {
        this.asleftdeviation = value;
    }

    /**
     * Gets the value of the asleftdevicetolerancefrom property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVICETOLERANCEFROM() {
        return asleftdevicetolerancefrom;
    }

    /**
     * Sets the value of the asleftdevicetolerancefrom property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVICETOLERANCEFROM(QUANTITY value) {
        this.asleftdevicetolerancefrom = value;
    }

    /**
     * Gets the value of the asleftdevicetoleranceto property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASLEFTDEVICETOLERANCETO() {
        return asleftdevicetoleranceto;
    }

    /**
     * Sets the value of the asleftdevicetoleranceto property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASLEFTDEVICETOLERANCETO(QUANTITY value) {
        this.asleftdevicetoleranceto = value;
    }

    /**
     * Gets the value of the asleftstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getASLEFTSTATUS() {
        return asleftstatus;
    }

    /**
     * Sets the value of the asleftstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setASLEFTSTATUS(STATUS_Type value) {
        this.asleftstatus = value;
    }

}
